from flask import Flask, render_template, jsonify
import requests

app = Flask(__name__)

# API endpoint and headers
API_URL = "https://trade.tr.playblackdesert.com/Home/GetWorldMarketSubList"
HEADERS = {
    "content-type": "application/x-www-form-urlencoded; charset=UTF-8",
    "user-agent": "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/62.0.3202.9 Safari/537.36",
    "cookie": "__RequestVerificationToken=_GZNqipVyt_xx0yyHHiUxi5qwNF_PFyne7UX_QViA5CZAn_A6QFuSfKzACF275nZ3eDNtawHZdzco4PDmW4GFF6bkLP_z6KSQOV52hJw2n81"  # replace with actual cookie
}

# Main keys and division factors for each ID and subKey
DIVISION_FACTORS = {
    11853: {4: 72, 5: 720},
    11875: {4: 72, 5: 720},
    11607: {4: 30, 5: 300},
    11630: {4: 30, 5: 300},
    12060: {4: 22, 5: 225},
    12031: {4: 20, 5: 200},
    12236: {4: 17, 5: 175},
    12230: {4: 15, 5: 150},
    11628: {4: 7, 5: 70},
    12061: {4: 55, 5: 550},
    12237: {4: 40, 5: 400},
    11629: {4: 37, 5: 375},
    11828: {4: 25, 5: 250},
    11855: {4: 78, 5: 780},
    12068: {4: 60, 5: 600},
    12257: {4: 35, 5: 350},
    11663: {4: 25, 5: 250},
    12032: {4: 25, 5: 250},
    11834: {4: 20, 5: 200},
    12042: {4: 10, 5: 100},
    11662: {4: 81, 5: 815},
    12091: {4: 42, 5: 425},
    11856: {4: 42, 5: 425},
    12229: {4: 20, 5: 200},
    12251: {4: 12, 5: 125},
    11625: {4: 9, 5: 90}
    # Add all remaining entries here as you listed
}

# Function to fetch data
def fetch_data():
    data = []
    for main_key, subkey_dict in DIVISION_FACTORS.items():
        payload = {
            "__RequestVerificationToken": "JY5T_WX59KyeSZXKk-3jdNWxdklccwGOob9ztvBxPPlmfBAkfJAensFqpILhrlCLCYmWi_o41VcKb8TJcgoJuJYFwtKMhDYpKkUktpgD5581",  # replace with actual token
            "mainKey": main_key
        }
        response = requests.post(API_URL, headers=HEADERS, data=payload)

        if response.status_code == 200:
            json_data = response.json()
            if json_data["resultCode"] == 0:
                # Filter for specific subKeys and calculate the optimized price
                for item in json_data["detailList"]:
                    subkey = item["subKey"]
                    if subkey in subkey_dict:
                        divide_by = subkey_dict[subkey]
                        optimized_price = (item["pricePerOne"] // divide_by) + 5000000
                        data.append({
                            "ID": main_key,
                            "Image": f"https://s1.pearlcdn.com/TR/TradeMarket/Common/img/BDO/item/{main_key}.png",
                            "Name": item["name"],
                            "SubKey": subkey,
                            "Original Price": item["pricePerOne"],
                            "Optimized Price": optimized_price,
                            "Count": item["count"]
                        })
    return data

@app.route('/')
def index():
    return render_template('index.html')

@app.route('/fetch_data')
def get_data():
    data = fetch_data()
    return jsonify(data)

if __name__ == "__main__":
    app.run(debug=True, port=1111)
